@@ -44,4 +44,8 @@ def fetch_external_dependencies():
         get_ausaxs()
     except Exception as e:
         print("Download of external dependencies failed.", e)
-    return
\ No newline at end of file
+    return
+
+
+if __name__ == "__main__":
+    fetch_external_dependencies()
