@@ -3,7 +3,7 @@
 
 """
 Run sasview in place.  This allows sasview to use the python
-files in the source tree without having to call setup.py install
+files in the source tree without having to call install the module
 first.  A rebuild is still necessary when working on sas models
 or c modules.
 
@@ -83,11 +83,6 @@ def prepare():
     #    with cd(root):
     #        subprocess.call((sys.executable, "setup.py", "build"), shell=False)
 
-    # Notify the help menu that the Sphinx documentation is in a different
-    # place than it otherwise would be.
-    docpath = joinpath(root, 'docs', 'sphinx-docs', '_build', 'html')
-    os.environ['SASVIEW_DOC_PATH'] = docpath
-
 import multiprocessing
 if __name__ == "__main__":
     multiprocessing.freeze_support()
