@@ -117,13 +117,10 @@ class SldPanel(QtWidgets.QDialog):
         self.ui.setupUi(self)
 
         # set validators
-        # TODO: GuiUtils.FormulaValidator() crashes with Qt5 - fix
-        #self.ui.editMolecularFormula.setValidator(GuiUtils.FormulaValidator(self.ui.editMolecularFormula))
+        # Chemical formula is checked via periodictable.formula module.
+        self.ui.editMolecularFormula.setValidator(GuiUtils.FormulaValidator(self.ui.editMolecularFormula))
 
-        # No need for recalculate
-        self.ui.recalculateButton.setVisible(False)
-
-        rx = QtCore.QRegularExpression("[+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?")
+        rx = QtCore.QRegularExpression(r"[+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?")
         self.ui.editMassDensity.setValidator(QtGui.QRegularExpressionValidator(rx, self.ui.editMassDensity))
         self.ui.editNeutronWavelength.setValidator(QtGui.QRegularExpressionValidator(rx, self.ui.editNeutronWavelength))
         self.ui.editXrayWavelength.setValidator(QtGui.QRegularExpressionValidator(rx, self.ui.editXrayWavelength))
@@ -131,7 +128,7 @@ class SldPanel(QtWidgets.QDialog):
         # signals
         self.ui.helpButton.clicked.connect(self.displayHelp)
         self.ui.closeButton.clicked.connect(self.closePanel)
-        self.ui.recalculateButton.clicked.connect(self.calculateSLD)
+        self.ui.calculateButton.clicked.connect(self.calculateSLD)
 
     def calculateSLD(self):
         self.recalculateSLD()
@@ -148,11 +145,6 @@ class SldPanel(QtWidgets.QDialog):
 
         #self.model.dataChanged.connect(self.dataChanged)
 
-        self.ui.editMassDensity.textChanged.connect(self.recalculateSLD)
-        self.ui.editMolecularFormula.textChanged.connect(self.recalculateSLD)
-        self.ui.editNeutronWavelength.textChanged.connect(self.recalculateSLD)
-        self.ui.editXrayWavelength.textChanged.connect(self.recalculateSLD)
-
         self.modelReset()
 
     def setupMapper(self):
