@@ -615,8 +615,22 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         if 'pr_params' in value:
             self.cbFitting.setCurrentIndex(self.cbFitting.findText('Inversion'))
             params = value['pr_params']
-            self.sendItemToPerspective(items[0])
-            self._perspective().updateFromParameters(params)
+            # Make the perspective read the rest of the read data
+            if not isinstance(params, list):
+                params = [params]
+            for page in params:
+            # Check if this set of parameters is for a batch page
+                            # if so, skip the update
+                if 'is_batch' in page and page['is_batch'][0] == 'True':
+                    continue
+                tab_index = None
+                if 'tab_index' in page:
+                    tab_index = page['tab_index'][0]
+                    tab_index = int(tab_index)
+                # Send current model item to the perspective
+                self.sendItemToPerspective(items[0], tab_index=tab_index)
+                # Assign parameters to the most recent (current) page. 
+                self._perspective().updateFromParameters(page)
         if 'invar_params' in value:
             self.cbFitting.setCurrentIndex(self.cbFitting.findText('Invariant'))
             self.sendItemToPerspective(items[0])
@@ -1114,7 +1128,7 @@ class DataExplorerWindow(DroppableDataLoadWidget):
 
         append = False
         plot_to_append_to = None
-        for plot_to_show in plots_to_show:
+        for idx, plot_to_show in enumerate(plots_to_show):
             # Check if this plot already exists
             shown = self.updatePlot(plot_to_show)
             # Retain append status throughout loop
@@ -1145,8 +1159,15 @@ class DataExplorerWindow(DroppableDataLoadWidget):
                 self.appendOrUpdatePlot(self, plot_to_show, plot_to_append_to)
             else:
                 # Plots with main data points on the same chart
-                # Get the main data plot unless data is 2D which is plotted earlier
-                if main_data is not None and not isinstance(main_data, Data2D):
+                # If this is the first plot in the list (and ONLY if the first)
+                # get the main data plot unless data is 2D which is plotted earlier
+                # or the DataRole is ROLE_SIZE_DISTRIBUTION
+                if (
+                    idx == 0
+                    and main_data is not None
+                    and not isinstance(main_data, Data2D)
+                    and role != DataRole.ROLE_SIZE_DISTRIBUTION
+                ):
                     new_plots.append((plot_item, main_data))
                 new_plots.append((plot_item, plot_to_show))
 
@@ -1215,7 +1236,8 @@ class DataExplorerWindow(DroppableDataLoadWidget):
                     plot_set.xtransform = 'log10(x)'
                 if (plot_set.plot_role in [
                     DataRole.ROLE_POLYDISPERSITY, DataRole.ROLE_RESIDUAL, DataRole.ROLE_RESIDUAL_SESANS,
-                    DataRole.ROLE_ANGULAR_SLICE, DataRole.ROLE_STAND_ALONE] or plot_set.isSesans):
+                    DataRole.ROLE_ANGULAR_SLICE, DataRole.ROLE_STAND_ALONE,
+                    DataRole.ROLE_SIZE_DISTRIBUTION] or plot_set.isSesans):
                     plot_set.ytransform = 'y'
                 else:
                     plot_set.ytransform = 'log10(y)'
@@ -1839,26 +1861,6 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         self.model.clear()
         self.theory_model.clear()
 
-    def deleteSelectedItem(self):
-        """
-        Delete the current item
-        """
-        # Assure this is indeed wanted
-        delete_msg = "This operation will remove the selected data sets " +\
-                     "and all the dependents from SasView." +\
-                     "\nDo you want to continue?"
-        reply = QtWidgets.QMessageBox.question(self,
-                                               'Warning',
-                                               delete_msg,
-                                               QtWidgets.QMessageBox.Yes,
-                                               QtWidgets.QMessageBox.No)
-
-        if reply == QtWidgets.QMessageBox.No:
-            return
-
-        indices = self.current_view.selectedIndexes()
-        self.deleteIndices(indices)
-
     def deleteIndices(self, indices):
         """
         Delete model idices from the current view
@@ -1884,6 +1886,10 @@ class DataExplorerWindow(DroppableDataLoadWidget):
 
                 # Delete corresponding open plots
                 self.closePlotsForItem(item_to_delete)
+
+                # This needs to run before model.removeRow()
+                self.communicator.dataDeletedSignal.emit(deleted_items)
+
                 if item_to_delete.parent():
                     # We have a child item - delete from it
                     item_to_delete.parent().removeRow(row)
@@ -1892,9 +1898,6 @@ class DataExplorerWindow(DroppableDataLoadWidget):
                     model.removeRow(row)
             indices = self.current_view.selectedIndexes()
 
-        # Let others know we deleted data
-        self.communicator.dataDeletedSignal.emit(deleted_items)
-
         # update stored_data
         self.manager.update_stored_data(deleted_names)
 
@@ -1902,7 +1905,9 @@ class DataExplorerWindow(DroppableDataLoadWidget):
         """
         Close all currently displayed plots
         """
-
+        # results panel
+        self.parent.results_frame.setVisible(False)
+        # plots
         for plot_id in PlotHelper.currentPlotIds():
             try:
                 plotter = PlotHelper.plotById(plot_id)
