@@ -1,5 +1,6 @@
 import numpy
 import copy
+import re
 
 from typing import Optional
 
@@ -60,6 +61,10 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
         # The tabs need to be movabe
         self.setMovable(True)
 
+        # Remember the last tab closed
+        self.lastTabClosed = None
+        self.installEventFilter(self)
+
         self.communicate = self.parent.communicator()
 
         # Initialize the first tab
@@ -95,6 +100,14 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
         self.plusButton.setToolTip("Add a new Fit Page")
         self.plusButton.clicked.connect(lambda: self.addFit(None))
 
+    def eventFilter(self, widget, event):
+        if event.type() == QtCore.QEvent.KeyPress:
+            key = event.key()
+            # check for Ctrl-T press
+            if key == QtCore.Qt.Key_T and event.modifiers() == QtCore.Qt.ControlModifier:
+                self.addClosedTab()
+                return True
+        return QtCore.QObject.eventFilter(self, widget, event)
 
     def updateWindowTitle(self):
         """
@@ -260,7 +273,7 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
         self.tabs.append(tab)
         if data:
             self.updateFitDict(data, tab_name)
-        self.maxIndex = max([tab.tab_id for tab in self.tabs], default=0) + 1
+        self.maxIndex = self.nextAvailableTabIndex()
 
         icon = QtGui.QIcon()
         if is_batch:
@@ -271,6 +284,34 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
         # Notify listeners
         self.tabsModifiedSignal.emit()
 
+    def nextAvailableTabIndex(self):
+        """
+        Returns the index of the next available tab
+        """
+        return max((tab.tab_id for tab in self.tabs), default=0) + 1
+
+    def addClosedTab(self):
+        """
+        Recover the deleted tab.
+        The tab is held in self.lastTabClosed
+        """
+        if self.lastTabClosed is None:
+            return
+        tab = self.lastTabClosed
+        icon = QtGui.QIcon()
+        # tab_name = self.getTabName()
+        tab_name = "FitPage" + str(tab.tab_id)
+        ObjectLibrary.addObject(tab_name, tab)
+        self.addTab(tab, icon, tab_name)
+        # Update the list of tabs
+        self.tabs.append(tab)
+        # Show the new tab
+        self.setCurrentWidget(tab)
+        # lastTabClosed is no longer valid
+        self.lastTabClosed = None
+        # Notify listeners
+        self.tabsModifiedSignal.emit()
+
     def addConstraintTab(self):
         """
         Add a new C&S fitting tab
@@ -325,7 +366,10 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
         try:
             ObjectLibrary.deleteObjectByRef(self.tabs[index])
             self.removeTab(index)
-            del self.tabs[index]
+            # can't just delete the tab, since we still hold a reference to it
+            # del self.tabs[index]
+            # Instead, we just recreate self.tabs without the deleted tab
+            self.tabs = [tab for tab in self.tabs if tab is not self.tabs[index]]
             self.tabsModifiedSignal.emit()
         except IndexError:
             # The tab might have already been deleted previously
@@ -348,8 +392,15 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
         """
         Update local bookkeeping on tab close
         """
+        # update the last-tab closed information
+        # this should be done only for regular fitting
+        if not isinstance(self.tabs[index], ConstraintWidget) and \
+              not self.tabs[index].is_batch_fitting:
+            self.lastTabClosed = self.tabs[index]
+
         # don't remove the last tab
         if len(self.tabs) <= 1:
+            # remove the tab from the tabbed group
             self.resetTab(index)
             return
         self.closeTabByIndex(index)
@@ -376,6 +427,9 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
                 if index_to_delete_str in tab_key:
                     for tab_name in orig_dict[tab_key]:
                         self.closeTabByName(tab_name)
+                        # assure that lastTabClosed is null if it references the deleted data
+                        if self.lastTabClosed and tab_name == "FitPage"+str(self.lastTabClosed.tab_id):
+                                self.lastTabClosed = None
                     self.dataToFitTab.pop(tab_key)
 
     def allowBatch(self):
@@ -433,7 +487,7 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
                 return
             if numpy.any(available_tabs):
                 first_good_tab = available_tabs.index(True)
-                self.tabs[first_good_tab].data = data
+                self.tabs[first_good_tab].dataFromItems(data)
                 tab_name = str(self.tabText(first_good_tab))
                 self.updateFitDict(data, tab_name)
             else:
@@ -455,7 +509,7 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
             msg = "Data in Batch Fitting cannot be swapped"
             raise RuntimeError(msg)
 
-        self.currentTab.data = data
+        self.currentTab.dataFromItems(data)
         tab_name = str(self.tabText(self.currentIndex()))
         self.updateFitDict(data, tab_name)
 
@@ -573,7 +627,7 @@ class FittingWindow(QtWidgets.QTabWidget, Perspective):
         """
         assert isinstance(name, str)
         for tab in self.tabs:
-            if tab.modelName() == name:
+            if hasattr(tab, 'modelName') and tab.modelName() == name:
                 return tab
         return None
 
