@@ -551,11 +551,11 @@ class FittingWidgetTest:
         assert widget.poly_params_to_fit == ['radius_bell.width', 'length.width']
 
         # Change the min/max values
-        assert widget.kernel_module.details['radius_bell.width'][1] == 0.0
+        assert widget.logic.kernel_module.details['radius_bell.width'][1] == 0.0
         widget._poly_model.item(0,2).setText("1.0")
-        assert widget.kernel_module.details['radius_bell.width'][1] == 1.0
+        assert widget.logic.kernel_module.details['radius_bell.width'][1] == 1.0
         # Check that changing the polydispersity min/max value doesn't affect the paramer min/max
-        assert widget.kernel_module.details['radius_bell'][1] == 0.0
+        assert widget.logic.kernel_module.details['radius_bell'][1] == 0.0
 
         #widget.show()
         #QtWidgets.QApplication.exec_()
@@ -565,14 +565,14 @@ class FittingWidgetTest:
         widget._poly_model.item(0,4).setText("22")
         assert widget.poly_params['radius_bell.npts'] == 22
         # test that sasmodel is updated with the new value
-        assert widget.kernel_module.getParam('radius_bell.npts') == 22
+        assert widget.logic.kernel_module.getParam('radius_bell.npts') == 22
 
         # Change the pd value
         assert widget.poly_params['radius_bell.width'] == 0.0
         widget._poly_model.item(0,1).setText("0.8")
         assert widget.poly_params['radius_bell.width'] == pytest.approx(0.8, abs=1e-7)
         # Test that sasmodel is updated with the new value
-        assert widget.kernel_module.getParam('radius_bell.width') == pytest.approx(0.8, abs=1e-7)
+        assert widget.logic.kernel_module.getParam('radius_bell.width') == pytest.approx(0.8, abs=1e-7)
 
         # Uncheck pd in the fitting widget
         widget.chkPolydispersity.setCheckState(2)
@@ -580,7 +580,7 @@ class FittingWidgetTest:
         # Should not change the value of the qt model
         assert widget.poly_params['radius_bell.width'] == pytest.approx(0.8, abs=1e-7)
         # sasmodel should be set to 0
-        assert widget.kernel_module.getParam('radius_bell.width') == pytest.approx(0.0, abs=1e-7)
+        assert widget.logic.kernel_module.getParam('radius_bell.width') == pytest.approx(0.0, abs=1e-7)
 
         # try something stupid
         widget._poly_model.item(0,4).setText("butt")
@@ -610,8 +610,8 @@ class FittingWidgetTest:
         # call method with default settings
         widget.onPolyComboIndexChange('gaussian', 0)
         # check values
-        assert widget.kernel_module.getParam('radius_bell.npts') == 35
-        assert widget.kernel_module.getParam('radius_bell.nsigmas') == 3
+        assert widget.logic.kernel_module.getParam('radius_bell.npts') == 35
+        assert widget.logic.kernel_module.getParam('radius_bell.nsigmas') == 3
         # Change the index
         widget.onPolyComboIndexChange('rectangle', 0)
         # check values
@@ -1203,10 +1203,10 @@ class FittingWidgetTest:
 
         # check that the value has been modified in kernel_module
         assert new_value == \
-                         str(widget.kernel_module.params[name_modified_param])
+                         str(widget.logic.kernel_module.params[name_modified_param])
 
         # check that range of variation for this parameter has NOT been changed
-        assert new_value not in widget.kernel_module.details[name_modified_param]
+        assert new_value not in widget.logic.kernel_module.details[name_modified_param]
 
     def testModelContextMenu(self, widget):
         """
