@@ -5,10 +5,12 @@ from .Fitting.FittingPerspective import FittingWindow
 from .Invariant.InvariantPerspective import InvariantWindow
 from .Inversion.InversionPerspective import InversionWindow
 from .Corfunc.CorfuncPerspective import CorfuncWindow
+from .SizeDistribution.SizeDistributionPerspective import SizeDistributionWindow
 
 PERSPECTIVES = {
     FittingWindow.name: FittingWindow,
     InvariantWindow.name: InvariantWindow,
     InversionWindow.name: InversionWindow,
     CorfuncWindow.name: CorfuncWindow,
-}
\ No newline at end of file
+    SizeDistributionWindow.name: SizeDistributionWindow,
+}
