@@ -67,7 +67,6 @@ class SectorInteractor(BaseInteractor, SlicerModel):
                                         phi=self.phi, theta2=self.theta2)
         self.left_line.update(left=True)
         self.left_line.qmax = self.qmax
-        self.fold = True
         # draw the sector
         self.update()
         self._post_data()
@@ -152,7 +151,6 @@ class SectorInteractor(BaseInteractor, SlicerModel):
                        phi_min=phimin + numpy.pi,
                        phi_max=phimax + numpy.pi, nbins=nbins)
 
-        sect.fold = self.fold
         sector = sect(self.data)
         # Create 1D data resulting from average
 
@@ -180,19 +178,21 @@ class SectorInteractor(BaseInteractor, SlicerModel):
             new_plot.ytransform = 'y'
             new_plot.yaxis("\\rm{Residuals} ", "/")
 
+        new_plot.group_id = "2daverage" + self.data.name
         new_plot.id = "SectorQ" + self.data.name
-        new_plot.type_id = "Slicer" + self.data.name # Used to remove plots after changing slicer so they don't keep showing up after closed
         new_plot.is_data = True
+
         item = self._item
         if self._item.parent() is not None:
             item = self._item.parent()
         GuiUtils.updateModelItemWithPlot(item, new_plot, new_plot.id)
-
         self.base.manager.communicator.plotUpdateSignal.emit([new_plot])
         self.base.manager.communicator.forcePlotDisplaySignal.emit([item, new_plot])
 
         if self.update_model:
             self.setModelFromParams()
+        self.draw()
+
 
     def validate(self, param_name, param_value):
         """
@@ -252,7 +252,6 @@ class SectorInteractor(BaseInteractor, SlicerModel):
         params["Phi [deg]"] = self.main_line.theta * 180 / numpy.pi
         params["Delta_Phi [deg]"] = numpy.fabs(self.left_line.phi * 180 / numpy.pi)
         params["nbins"] = self.nbins
-        params["fold"] = self.fold
         return params
 
     def setParams(self, params):
@@ -272,7 +271,6 @@ class SectorInteractor(BaseInteractor, SlicerModel):
             params["Delta_Phi [deg]"] = MIN_PHI
 
         self.nbins = int(params["nbins"])
-        self.fold =params["fold"]
         self.main_line.theta = main
         # Reset the slicer parameters
         self.main_line.update()
@@ -427,6 +425,8 @@ class SideInteractor(BaseInteractor):
         self.theta = numpy.arctan2(y, x)
         self.has_move = True
         if not self.left_moving:
+
+
             if  self.theta2 - self.theta <= 0 and self.theta2 > 0:
                 self.restore(ev)
                 return
@@ -449,17 +449,22 @@ class SideInteractor(BaseInteractor):
         else:
             if  self.theta < 0 and (self.theta + numpy.pi * 2 - self.theta2) <= 0:
                 self.restore(ev)
+
                 return
             elif self.theta2 < 0 and (self.theta - self.theta2) <= 0:
                 self.restore(ev)
                 return
             elif  self.theta > 0 and self.theta - self.theta2 <= 0:
+
                 self.restore(ev)
+
                 return
             elif self.theta - self.theta2 >= numpy.pi / 2 or  \
                 ((self.theta + numpy.pi * 2 - self.theta2) >= numpy.pi / 2 and \
                  self.theta < 0 and self.theta2 > 0):
+
                 self.restore(ev)
+
                 return
 
         self.phi = numpy.fabs(self.theta2 - self.theta)
