@@ -3,6 +3,7 @@ BumpsFitting module runs the bumps optimizer.
 """
 import logging
 import os
+from copy import deepcopy
 from datetime import timedelta, datetime
 import traceback
 import uncertainties
@@ -35,6 +36,9 @@ from sas.sascalc.fit.AbstractFitEngine import FitEngine
 from sas.sascalc.fit.AbstractFitEngine import FResult
 from sas.sascalc.fit.expression import compile_constraints
 
+# patch uncertainties.core.AffineScalarFunc to work with float() conversion
+uncertainties.core.AffineScalarFunc.__float__ = lambda self: float(self.nominal_value)
+
 class Progress(object):
     def __init__(self, history, max_step, pars, dof):
         remaining_time = int(history.time[0]*(float(max_step)/history.step[0]-1))
@@ -298,17 +302,17 @@ class BumpsFit(FitEngine):
             # Use the standard error as the error in the parameter
             for param, val, err in zip(varying, values, errs):
                 # Convert all varying parameters to uncertainties objects
-                param.value = uncertainties.ufloat(val, err)
+                param.slot = uncertainties.ufloat(val, err)
         else:
             try:
                 # Use the covariance matrix to calculate error in the parameter
                 fitted = uncertainties.correlated_values(values, cov)
                 for param, val in zip(varying, fitted):
-                    param.value = val
+                    param.slot = val
             except Exception:
                 # No convergence. Convert all varying parameters to uncertainties objects
                 for param, val, err in zip(varying, values, errs):
-                    param.value = uncertainties.ufloat(val, err)
+                    param.slot = uncertainties.ufloat(val, err)
 
         # Propagate correlated uncertainty through constraints.
         problem.setp_hook()
@@ -320,7 +324,14 @@ class BumpsFit(FitEngine):
         uncertainty_warning = False
 
         for fitting_module in problem.models:
-            fitness = fitting_module.fitness
+            # CRUFT: This makes BumpsFitting compatible with bumps v0.9 and v1.0
+            if isinstance(fitting_module, SasFitness):
+                # Bumps v1.x+ - A Fitness object is returned
+                fitness = fitting_module
+            else:
+                # Bumps v0.x - A module is returned that holds the Fitness object
+                fitness = fitting_module.fitness
+            fitness = deepcopy(fitness)
             pars = fitness.fitted_pars + fitness.computed_pars
             par_names = fitness.fitted_par_names + fitness.computed_par_names
 
@@ -332,33 +343,33 @@ class BumpsFit(FitEngine):
             # TODO: should scale stderr by sqrt(chisq/DOF) if dy is unknown
             fitting_result.success = result['success']
             fitting_result.convergence = result['convergence']
-            if result['uncertainty'] is not None:
-                fitting_result.uncertainty_state = result['uncertainty']
-
-            fitting_result.pvec = np.array([getattr(p.value, 'n', p.value) for p in pars])
-            fitting_result.stderr = np.array([getattr(p.value, 's', 0) for p in pars])
+            uncertainty = result['uncertainty']
+            if hasattr(uncertainty, "draw"):
+                fitting_result.uncertainty_state = uncertainty
+            fitting_result.pvec = np.array([getattr(p.slot, 'n', p.slot) for p in pars if hasattr(p, 'slot')])
+            fitting_result.stderr = np.array([getattr(p.slot, 's', 0) for p in pars if hasattr(p, 'slot')])
             DOF = max(1, fitness.numpoints() - len(fitness.fitted_pars))
             fitting_result.fitness = np.sum(fitting_result.residuals ** 2) / DOF
 
             # Warn user about any parameter that is not an uncertainty object
-            miss_uncertainty = [p for p in pars if not isinstance(p.value,
-                              (uncertainties.core.Variable, uncertainties.core.AffineScalarFunc))]
+            miss_uncertainty = [p for p in pars if hasattr(p, 'slot') and not isinstance(p.slot,
+                                (uncertainties.core.Variable, uncertainties.core.AffineScalarFunc))]
             if miss_uncertainty:
                 uncertainty_warning = True
                 for p in miss_uncertainty:
-                    logging.warn(p.name + " uncertainty could not be calculated.")
+                    logging.warning(p.name + " uncertainty could not be calculated.")
 
            # TODO: Let the GUI decided how to handle success/failure.
             if not fitting_result.success:
-                fitting_result.stderr[:] = np.NaN
-                fitting_result.fitness = np.NaN
+                fitting_result.stderr[:] = np.nan
+                fitting_result.fitness = np.nan
 
             all_results.append(fitting_result)
 
         all_results[0].mesg = result['errors']
 
         if uncertainty_warning:
-            logging.warn("Consider checking related constraint definitions and status of parameters used there.")
+            logging.warning("Consider checking related constraint definitions and status of parameters used there.")
 
         if q is not None:
             q.put(all_results)
@@ -402,7 +413,7 @@ def run_bumps(problem, handler, curr_thread):
     try:
         best, fbest = fitdriver.fit()
     except Exception as exc:
-        best, fbest = None, np.NaN
+        best, fbest = None, np.nan
         errors.extend([str(exc), traceback.format_exc()])
     finally:
         mapper.stop_mapper(fitdriver.mapper)
@@ -415,7 +426,7 @@ def run_bumps(problem, handler, curr_thread):
     success = best is not None
     try:
         stderr = fitdriver.stderr() if success else None
-        if hasattr(fitdriver.fitter, 'state'):
+        if hasattr(fitdriver.fitter, 'state') and hasattr(fitdriver.fitter.state, 'draw'):
             x = fitdriver.fitter.state.draw().points
             n_parameters = x.shape[1]
             cov = np.cov(x.T, bias=True).reshape((n_parameters, n_parameters))
