@@ -1,8 +1,6 @@
 """
     Utilities to manage models
 """
-from __future__ import print_function
-
 import os
 import sys
 import time
@@ -13,11 +11,9 @@ import py_compile
 import shutil
 import io
 
-from six import reraise
-
 from sasmodels.sasview_model import load_custom_model, load_standard_models
 
-from sas.system.user import get_user_dir
+from sas.system.user import get_plugin_dir
 
 # Explicitly import from the pluginmodel module so that py2exe
 # places it in the distribution. The Model1DPlugin class is used
@@ -28,7 +24,7 @@ logger = logging.getLogger(__name__)
 
 
 PLUGIN_DIR = 'plugin_models'
-PLUGIN_LOG = os.path.join(get_user_dir(), PLUGIN_DIR, "plugins.log")
+PLUGIN_LOG = os.path.join(get_plugin_dir(), "plugins.log")
 PLUGIN_NAME_BASE = '[plug-in] '
 
 
@@ -84,29 +80,14 @@ def _check_plugin(model, name):
     return model
 
 
-def find_plugins_dir():
+def find_plugins_dir() -> str:
+    """A helper function that returns a string representation of the plugins directory as defined by sas.system.user.
     """
-    Find path of the plugins directory.
-    The plugin directory is located in the user's home directory.
-    """
-    path = os.path.join(os.path.expanduser("~"), '.sasview', PLUGIN_DIR)
-
-    # TODO: trigger initialization of plugins dir from installer or startup
-    # If the plugin directory doesn't exist, create it
-    if not os.path.isdir(path):
-        os.makedirs(path)
-    # TODO: should we be checking for new default models every time?
-    # TODO: restore support for default plugins
-    #initialize_plugins_dir(path)
-    return path
+    return str(get_plugin_dir())
 
 
 def initialize_plugins_dir(path):
     # TODO: There are no default plugins
-    # TODO: Default plugins directory is in sasgui, but models.py is in sascalc
-    # TODO: Move default plugins beside sample data files
-    # TODO: Should not look for defaults above the root of the sasview install
-
     # Walk up the tree looking for default plugin_models directory
     base = os.path.abspath(os.path.dirname(__file__))
     for _ in range(12):
@@ -139,7 +120,7 @@ class ReportProblem(object):
         type, value, tb = sys.exc_info()
         if type is not None and issubclass(type, py_compile.PyCompileError):
             print("Problem with", repr(value))
-            reraise(type, value, tb)
+            raise value
         return 1
 
 report_problem = ReportProblem()
