@@ -5,9 +5,13 @@
 import sys
 import os.path
 import unittest, math, numpy
-from sas.sascalc.pr.invertor import Invertor
+# TODO: This import is broken. It needs to be rewritten if this test is to be renabled.
+# from sas.sascalc.pr.invertor import Invertor
+import pytest
 from sas.sascalc.pr.distance_explorer import DistExplorer
 
+pytest.skip(reason="Refactored invertor doesn't support this test", allow_module_level=True)
+
 try:
     from utest_invertor import load
 except ImportError:
